require "safe_yaml/load"

# Simple middleware to set custom http headers
class Oxy::CustomHeaders
  def initialize(app, options)
    @app, @custom_headers = app, load_from_file(options)
  end

  def call(env)
    response = @app.call(env)
    headers = Rack::Utils::HeaderHash.new(response[1])
    response[1] = headers.merge(@custom_headers)
    response
  end

private
  def load_from_file(options)
    # parse custom headers from _config.yml
    filename = File.join(options.document_root, "_config.yml")
    conf = SafeYAML.load_file(filename) if File.exist?(filename)
    # yield custom headers (if any)
    if conf && conf.key?("webrick") && conf["webrick"]
      headers = conf["webrick"]["headers"]
    end
    # default to empty headers (if necessary)
    headers || {}
  end
end